import requests
import pandas as pd


class Client():
    """
    Description: 

    Attributes:
        attr_a username : string -> Authentication
        attr_b : string -> Authentication
    """

    def __init__(self, email, password):
        self.email = email
        self.password = password
        self.url = f'http://147.182.201.104/messages/package_authentication/{self.email}/{self.password}/'
        

    @property
    def authenticated(self):
        url = self.url
        print()
        response = requests.get(url=url)
        print(response)
        if response.status_code == 200:
            print('Authencated')
            return True
        else:
            return False
        
    def send_bulk_sms(self, message, csv, title):
        print(self.authenticated)
        contacts = ''
        df = pd.read_csv(csv)
        msg = 0
        for index, row in df.iterrows():
            initial_number = row['numbers']
            
            contacts += str(initial_number) + ','
            msg += 1
        print(contacts, )
        if self.authenticated:
            url = f'http://147.182.201.104/messages/intelli_gateway_package_api/{self.email}/0/{contacts}/True/{title}/{message}/{msg}/'
            response = requests.get(url)
            print(url)
            print(response)
            return response
        else:
            raise Exception('Your are not authenticated')

    def send_single_sms(self, message, receiver, title):
        if self.authenticated:
            url = f'http://147.182.201.104/messages/intelli_gateway_package_api/{self.email}/{receiver}/0/False/{title}/{message}/0/'
            response = requests.get(url)
            print(url)
            print(response)
            return response
        else:
            raise Exception('Your are not authenticated')



import setuptools
from setuptools import setup

with open('README.md') as fh:
    long_description = fh.read()


setup(
  name = 'intelli-sms-gateway',         # How you named your package folder (MyLib)
  long_description=long_description,
  long_description_content_type='text/markdown',
  version = '0.0.8',      # Start with a small number and increase it with every change you make
  license = 'MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A package extending developable features of the Intelli-Africa Solutions SMS Gateway',   # Give a short description about your library
  author = 'Intelli Africa Solutions',                   # Type in your name
  author_email = 'info@intelliafrica.solutions',      # Type in your E-Mail
  keywords = ['SMS', 'Bulk Sms', 'Bulk Email'],   # Keywords that define your package best
  py_modules=['intelli-sms-gateway'],
  packages=setuptools.find_packages(),
  install_requires=[
          'requests',
          'pandas',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    "License :: OSI Approved :: MIT License", # Again, pick a license
    'Programming Language :: Python :: 3.6',
    "Operating System :: OS Independent",
  ],
)